@@ -1032,14 +1032,13 @@ QString KNetworkConfigParser::getPlatformInfo(QDomElement platform){
 /** Shows the dialog with all the supported platforms by GST. */
 void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
     KDialog *dialog= new KDialog( 0 );
-    KSelectDistroDlg* widget = new KSelectDistroDlg(dialog);
-    connect(widget->kpbOk,SIGNAL(clicked()),dialog,SLOT(accept()));
-    connect(widget->kpbCancel,SIGNAL(clicked()),dialog,SLOT(reject()));
+    QWidget *main = new QWidget(dialog);
+    dialog->setMainWidget(main);
+    KSelectDistroDlg* widget = new KSelectDistroDlg( main );
     connect(widget->klbDistroList,SIGNAL(doubleClicked(Q3ListBoxItem*)),dialog,SLOT(accept()));
     dialog->setSizeGripEnabled(true);
 
-
-  for ( QStringList::Iterator it = supportedPlatformsList.begin(); it != supportedPlatformsList.end(); ++it )
+    for ( QStringList::Iterator it = supportedPlatformsList.begin(); it != supportedPlatformsList.end(); ++it )
   {
     QString key = (*it);
     key = key.section(":",0,0);
